summaryrefslogtreecommitdiff
path: root/amiga/schedule.h
diff options
context:
space:
mode:
authorChris Young <chris@unsatisfactorysoftware.co.uk>2014-11-22 16:24:26 +0000
committerChris Young <chris@unsatisfactorysoftware.co.uk>2014-11-22 16:27:39 +0000
commit2de1553a002aff7fa89bb466cdba1b3414413901 (patch)
tree2ad599d6f20e8280036b6d464d070fdeb1359071 /amiga/schedule.h
parentf8d8d218d8d5f7fdeb2edc0c5fa3f0a22e6d5a1b (diff)
downloadnetsurf-2de1553a002aff7fa89bb466cdba1b3414413901.tar.gz
netsurf-2de1553a002aff7fa89bb466cdba1b3414413901.tar.bz2
New scheduler
Diffstat (limited to 'amiga/schedule.h')
-rwxr-xr-xamiga/schedule.h19
1 files changed, 11 insertions, 8 deletions
diff --git a/amiga/schedule.h b/amiga/schedule.h
index 70255a96e..cfea4d917 100755
--- a/amiga/schedule.h
+++ b/amiga/schedule.h
@@ -1,5 +1,5 @@
/*
- * Copyright 2008 Chris Young <chris@unsatisfactorysoftware.co.uk>
+ * Copyright 2008-2014 Chris Young <chris@unsatisfactorysoftware.co.uk>
*
* This file is part of NetSurf, http://www.netsurf-browser.org/
*
@@ -34,20 +34,23 @@
nserror ami_schedule(int t, void (*callback)(void *p), void *p);
/**
- * Process events up to current time.
+ * Handle a message received from the scheduler process.
*
- * This implementation only takes the top entry off the heap, it does not
- * venture to later scheduled events until the next time it is called -
- * immediately afterwards, if we're in a timer signalled loop.
+ * \param nsmsgport Message port to process.
*/
-void schedule_run(void);
+void ami_schedule_handle(struct MsgPort *nsmsgport);
/**
* Create a new process for the scheduler.
*
* \param nsmsgport Message port to send timer events to.
* \return NSERROR_OK on success or error code on faliure.
*/
nserror ami_scheduler_process_create(struct MsgPort *nsmsgport);
+
+/**
+ * Signal the scheduler process to exit.
+ */
+void ami_scheduler_process_delete(void);
#endif
@@ -34,20 +34,23 @@
* Create a new process for the scheduler.
*
- * \param nsmsgport Message port to send timer events to.
- * \return NSERROR_OK on success or error code on faliure.
+ * \param nsmsgport Message port for the scheduler to send events to.
+ * \return NSERROR_OK on success or error code on failure.
*/
nserror ami_scheduler_process_create(struct MsgPort *nsmsgport);